package com.jqtx.windows.command;

import com.alibaba.fastjson.JSON;
import com.jqtx.windows.common.exception.BizException;
import com.jqtx.windows.common.factory.AbstractCommand;
import com.jqtx.windows.common.factory.RuntimeContextHolder;
import com.jqtx.windows.component.LoanComponent;
import com.jqtx.windows.component.model.LoanModel;
import com.jqtx.windows.infrastructure.enums.ExceptionCodeEnum;
import com.jqtx.windows.web.response.JsonResult;
import com.jqtx.windows.web.response.LoanDetailResponse;
import com.jqtx.windows.web.response.LoanSubmitResponse;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Objects;

/**
 * 提现审核结果查询
 */
@Service
@Slf4j
public class LoanStatusCommand extends AbstractCommand {

    @Autowired
    private LoanComponent loanComponent;

    @Override
    public JsonResult execute() {
        String request = RuntimeContextHolder.currentRuntimeContext().getRequestBody();
        LoanSubmitResponse loanSubmitResponse = JSON.parseObject(request, LoanSubmitResponse.class);
        LoanModel byLoanNo = loanComponent.getByLoanNo(loanSubmitResponse.getLoanNo());

        LoanDetailResponse response = new LoanDetailResponse();
        response.setOrderNo(loanSubmitResponse.getOrderNo());
        response.setStatus(0);
        response.setRemark("提现审核中");
        if (Objects.isNull(byLoanNo)) {
            throw new BizException(ExceptionCodeEnum.BIZ_CREDIT_NOT_FOUND_ERROR);
        }
        if("PASS".equals(byLoanNo.getLoanCreditResult())){
            response.setStatus(1);
            response.setRemark("提现通过");
        }
        if("REFUSED".equals(byLoanNo.getLoanCreditResult())){
            response.setStatus(2);
            response.setRemark("提现拒绝，去别家看看");
        }
        return JsonResult.success(response);
    }
}
